AddressBlock

Struct AddressBlock 

#[non_exhaustive]
pub struct AddressBlock { pub offset: u32, pub size: u32, pub usage: AddressBlockUsage, pub protection: Option<Protection>, }
An uniquely mapped address block to a peripheral

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
offset: u32

Specifies the start address of an address block relative to the peripheral baseAddress.

size: u32

Specifies the number of addressUnitBits being covered by this address block.

usage: AddressBlockUsage

Usage of the address block.

protection: Option<Protection>

Specify the security privilege to access an address region

Implementations

Source

impl AddressBlock

pub fn builder() -> AddressBlockBuilder

Make a builder for AddressBlock

pub fn modify_from( &mut self, builder: AddressBlockBuilder, lvl: ValidateLevel, ) -> Result<(), SvdError>

Modify an existing AddressBlock based on a builder.

pub fn validate(&self, _lvl: ValidateLevel) -> Result<(), SvdError>

Validate the AddressBlock.

Notes

This doesn’t do anything.