DimElement

Struct DimElement 

#[non_exhaustive]
pub struct DimElement { pub dim: u32, pub dim_increment: u32, pub dim_index: Option<Vec<String>>, pub dim_name: Option<String>, pub dim_array_index: Option<DimArrayIndex>, }
Defines arrays and lists.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
dim: u32

Defines the number of elements in an array or list

dim_increment: u32

Specify the address increment between two neighboring array or list members in the address map

dim_index: Option<Vec<String>>

Specify the strings that substitue the placeholder %s within name and displayName. By default, is a value starting with 0

dim_name: Option<String>

Specify the name of the structure. If not defined, then the entry of the name element is used

dim_array_index: Option<DimArrayIndex>

Grouping element to create enumerations in the header file

Implementations

Source

impl DimElement

pub fn builder() -> DimElementBuilder

Make a builder for DimElement

pub fn parse_indexes(text: &str) -> Option<Vec<String>>

Get array of indexes from string

pub fn indexes_as_range(&self) -> Option<RangeInclusive<u32>>

Try to represent DimElement as range of integer indexes

pub fn modify_from( &mut self, builder: DimElementBuilder, lvl: ValidateLevel, ) -> Result<(), SvdError>

Modify an existing DimElement based on a builder.

pub fn validate(&self, _lvl: ValidateLevel) -> Result<(), SvdError>

Validate the DimElement.

Notes

This doesn’t do anything.

pub fn indexes(&self) -> Indexes<'_>

Get the indexes of the array or list.