EnumeratedValues

Struct EnumeratedValues 

#[non_exhaustive]
pub struct EnumeratedValues { pub name: Option<String>, pub usage: Option<Usage>, pub derived_from: Option<String>, pub values: Vec<EnumeratedValue>, }
A map describing unsigned integers and their description and name.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: Option<String>

Identifier for the whole enumeration section

usage: Option<Usage>

Usage of the values

derived_from: Option<String>

Makes a copy from a previously defined enumeratedValues section. No modifications are allowed

values: Vec<EnumeratedValue>

List of variants. The number of required items depends on the bit-width of the associated field.

Implementations

Source

impl EnumeratedValues

pub fn default_value(&self) -> Option<&EnumeratedValue>

Return default value if present

pub fn builder() -> EnumeratedValuesBuilder

Make a builder for EnumeratedValues

pub fn modify_from( &mut self, builder: EnumeratedValuesBuilder, lvl: ValidateLevel, ) -> Result<(), SvdError>

Modify an existing EnumeratedValues based on a builder.

pub fn validate(&self, lvl: ValidateLevel) -> Result<(), SvdError>

Validate the EnumeratedValues

pub fn validate_all(&self, lvl: ValidateLevel) -> Result<(), SvdError>

Validate the EnumeratedValues recursively.

pub fn usage(&self) -> Option<Usage>

Get the usage of these enumerated values.

pub fn get_value(&self, name: &str) -> Option<&EnumeratedValue>

Get enumeratedValue by name

pub fn get_mut_value(&mut self, name: &str) -> Option<&mut EnumeratedValue>

Get mutable enumeratedValue by name