pub enum ModifiedWriteValues {
    OneToClear,
    OneToSet,
    OneToToggle,
    ZeroToClear,
    ZeroToSet,
    ZeroToToggle,
    Clear,
    Set,
    Modify,
}
Describe the manipulation of data written to a register/field. If not specified, the value written to the field is the value stored in the field

Variants

OneToClear

Write data bit of one shall clear (set to zero) the corresponding bit in the field

OneToSet

Write data bit of one shall set (set to one) the corresponding bit in the field

OneToToggle

Write data bit of one shall toggle (invert) the corresponding bit in the field

ZeroToClear

Write data bit of zero shall clear (set to zero) the corresponding bit in the field

ZeroToSet

Write data bit of zero shall set (set to one) the corresponding bit in the field

ZeroToToggle

Write data bit of zero shall toggle (invert) the corresponding bit in the field

Clear

After a write operation all bits in the field are cleared (set to zero)

Set

After a write operation all bits in the field are set (set to one)

Modify

After a write operation all bit in the field may be modified (default)

Implementations

Parse a string into an ModifiedWriteValues value, returning Option::None if the string is not valid.

Convert this ModifiedWriteValues into a static string.